/*
 * Newt-Puzzle
 * Copyright (C) Aude Jaulent 2008, 2009 <elderme@tuxfamily.org>
 * 
 * Newt-Puzzle is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Newt-Puzzle is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _SCENE_H_
#define _SCENE_H_

#include <set>

#include "./display2D.h"
#include "./display3D.h"

#include "./graphicOptions.h"


class Scene
{
public:
	Scene();
	~Scene();
		
	GraphicOptions* getGraphicOptions();
	void setGraphicOptions(GraphicOptions *graphics);
		
	void clear();
				
	void deleteMeshesAndMaterials();
	void deleteUselessMeshesAndMaterials();
		
	//useful for debug
	void printMeshesAndMaterialsNames();

	void addDisplay2D(Display2D *disp2D);
	void addDisplay3D(Display3D *disp3D);
	void addDisplay3D(Display3D *disp3D, renderingMode rendering);
	void addGuiLayer(Display3D *guiLayer);

	void addMaterialInTheSet(Material *material);
	void addMeshInTheSet(Mesh *mesh, int nbTextures);		
		
		
	void initObjectsAndShaders ();
		
	int getHit(int bufSize, int xMouse, int yMouse, float delX, float delY, float distMax);		
	void render();

	void initGLParameters();
		
	void setClearColor(int numColor, float coeff);
	void setClearColor(Color color);
	
	Display2D* getDisplay2D(int i);
	Display3D* getDisplay3D(int i);
	Display3D* getGuiLayer(int i);
		
	void setCurrentGUI(int i);
	int getCurrentGUI();
		
		
private:
	std::vector<Display2D*> display2DList;
	std::vector<Display3D*> display3DList;
		
	int currentGUI;	
	std::vector<Display3D*> guiLayers;		
		
	std::set<Material*> materials;
	std::set<std::pair<Mesh*, int> > meshes;

	GraphicOptions *mpGraphics;
		
		
};

extern Scene *scene;


#endif // _SCENE_H_
