/*
 * Newt-Puzzle
 * Copyright (C) Aude Jaulent 2009 <elderme@tuxfamily.org>
 * 
 * Newt-Puzzle is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Newt-Puzzle is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _SCORE_H_
#define _SCORE_H_

#include <vector>

#include "newtEngine/entity.h"
#include "grid/entityWithValue.h"
#include "grid/entityLine.h"

#include "./variousEntities/cylinder.h"
#include "./variousEntities/torus.h"

class Score: public EntityWithPosition 
{
public:
	Score(std::vector<int> colors, int scoreMax, 
		  float baseRadius, int nbRbase, float baseHeight, 
		  float cylinderRadius, int nbRcyl,
		  float torusRadius, int nbTorus1, int nbTorus2,
		  Vector3 position);

	~Score();

	void incScore(int player, int delta); 
	int getScore(int player);
		
	void reinit();
		
protected:
	TorusMesh *torusMesh;
	int nbPlayers;

};


class PlayerScore: public EntityWithValue
{
public:
	PlayerScore(Material *material, CylinderMesh *cylinder, float baseRadius, 
				float cylinderHeight, float interval, int position, int nbPlayers);
	~PlayerScore();
			
	void applyTransformation ();		
	void incScore(int delta, TorusMesh *torusMesh);
	void reinit();	
	
protected:
	Vector3 mPosition;
	EntityLine *lineTorus;
};




#endif // _SCORE_H_
